==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/vo/EstimatesummarydetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算汇总子表
 * 
 * @author generator
 * 
 */
public class EstimatesummarydetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String inventoryCode; // 清单编码
    private java.lang.String engineeringName; // 工程名称或费用名称
    private java.math.BigDecimal engineeringScale; // 设计规模或者主要工程量
    private java.math.BigDecimal engineering; // 建筑工程费
    private java.math.BigDecimal purchase; // 安装购置费
    private java.math.BigDecimal installEngineering; // 安装工程
    private java.math.BigDecimal total; // 合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中

    private List<EstimatesummarydetailVO> children = new ArrayList<>();

    public List<EstimatesummarydetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<EstimatesummarydetailVO> children) {
        this.children = children;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 清单编码
     */
    public java.lang.String getInventoryCode() {
        return inventoryCode;
    }

    /**
     * 清单编码
     */
    public void setInventoryCode(java.lang.String inventoryCode) {
        this.inventoryCode = inventoryCode;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称或费用名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 设计规模或者主要工程量
     */
    public java.math.BigDecimal getEngineeringScale() {
        return engineeringScale;
    }

    /**
     * 设计规模或者主要工程量
     */
    public void setEngineeringScale(java.math.BigDecimal engineeringScale) {
        this.engineeringScale = engineeringScale;
    }
    /**
     * 建筑工程费
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 建筑工程费
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 安装购置费
     */
    public java.math.BigDecimal getPurchase() {
        return purchase;
    }

    /**
     * 安装购置费
     */
    public void setPurchase(java.math.BigDecimal purchase) {
        this.purchase = purchase;
    }
    /**
     * 安装工程
     */
    public java.math.BigDecimal getInstallEngineering() {
        return installEngineering;
    }

    /**
     * 安装工程
     */
    public void setInstallEngineering(java.math.BigDecimal installEngineering) {
        this.installEngineering = installEngineering;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/bedget/vo/EstimatesummarydetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算汇总子表
 *
 * @author generator
 *
 */
public class EstimatesummarydetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String inventoryCode; // 清单编码
    private java.lang.String engineeringName; // 工程名称或费用名称
    private java.math.BigDecimal engineeringScale; // 设计规模或者主要工程量
    private java.math.BigDecimal engineering; // 建筑工程费
    private java.math.BigDecimal purchase; // 安装购置费
    private java.math.BigDecimal installEngineering; // 安装工程
    private java.math.BigDecimal total; // 合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.math.BigDecimal other; // 其他

    private List<EstimatesummarydetailVO> children = new ArrayList<>();

    public List<EstimatesummarydetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<EstimatesummarydetailVO> children) {
        this.children = children;
    }

    public BigDecimal getOther() {
        return other;
    }

    public void setOther(BigDecimal other) {
        this.other = other;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 清单编码
     */
    public java.lang.String getInventoryCode() {
        return inventoryCode;
    }

    /**
     * 清单编码
     */
    public void setInventoryCode(java.lang.String inventoryCode) {
        this.inventoryCode = inventoryCode;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称或费用名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 设计规模或者主要工程量
     */
    public java.math.BigDecimal getEngineeringScale() {
        return engineeringScale;
    }

    /**
     * 设计规模或者主要工程量
     */
    public void setEngineeringScale(java.math.BigDecimal engineeringScale) {
        this.engineeringScale = engineeringScale;
    }
    /**
     * 建筑工程费
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 建筑工程费
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 安装购置费
     */
    public java.math.BigDecimal getPurchase() {
        return purchase;
    }

    /**
     * 安装购置费
     */
    public void setPurchase(java.math.BigDecimal purchase) {
        this.purchase = purchase;
    }
    /**
     * 安装工程
     */
    public java.math.BigDecimal getInstallEngineering() {
        return installEngineering;
    }

    /**
     * 安装工程
     */
    public void setInstallEngineering(java.math.BigDecimal installEngineering) {
        this.installEngineering = installEngineering;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }

}
